@@ -6,14 +6,15 @@ describe 'basic nova' do
 
     it 'should work with no errors' do
       pp= <<-EOS
-      include ::openstack_integration
-      include ::openstack_integration::repos
-      include ::openstack_integration::rabbitmq
-      include ::openstack_integration::mysql
-      include ::openstack_integration::keystone
-      include ::openstack_integration::neutron
-      include ::openstack_integration::placement
-      include ::openstack_integration::nova
+      include openstack_integration
+      include openstack_integration::repos
+      include openstack_integration::apache
+      include openstack_integration::rabbitmq
+      include openstack_integration::mysql
+      include openstack_integration::keystone
+      include openstack_integration::neutron
+      include openstack_integration::placement
+      include openstack_integration::nova
 
       nova_aggregate { 'test_aggregate':
         ensure            => present,
