@@ -42,7 +42,9 @@ describe 'nova::keystone::authtoken' do
         is_expected.to contain_nova_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('keystone_authtoken/interface').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -61,8 +63,7 @@ describe 'nova::keystone::authtoken' do
           :auth_type                            => 'password',
           :auth_version                         => 'v3',
           :cache                                => 'somevalue',
-          :cafile                               =>
-'/opt/stack/data/cafile.pem',
+          :cafile                               => '/opt/stack/data/cafile.pem',
           :certfile                             => 'certfile.crt',
           :delay_auth_decision                  => false,
           :enforce_token_bind                   => 'permissive',
@@ -78,17 +79,18 @@ describe 'nova::keystone::authtoken' do
           :memcache_secret_key                  => 'secret_key',
           :memcache_security_strategy           => 'ENCRYPT',
           :memcache_use_advanced_pool           => true,
-          :memcached_servers                    =>
-['memcached01:11211','memcached02:11211'],
+          :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
           :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :token_cache_time                     => '301',
-          :service_token_roles_required         => false,
+          :service_token_roles                  => ['service'],
+          :service_token_roles_required         => true,
+          :interface                            => 'internal',
         })
       end
 
       it 'configure keystone_authtoken' do
-        is_expected.to contain_nova_config('keystone_authtoken/www_authenticate_uri').with_value('https://10.0.0.1:9999/') 
+        is_expected.to contain_nova_config('keystone_authtoken/www_authenticate_uri').with_value('https://10.0.0.1:9999/')
         is_expected.to contain_nova_config('keystone_authtoken/username').with_value(params[:username])
         is_expected.to contain_nova_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_nova_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
@@ -119,7 +121,9 @@ describe 'nova::keystone::authtoken' do
         is_expected.to contain_nova_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_nova_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_nova_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
+        is_expected.to contain_nova_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_nova_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
+        is_expected.to contain_nova_config('keystone_authtoken/interface').with_value(params[:interface])
       end
 
       it 'installs python memcache package' do
