@@ -49,8 +49,11 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with_value('<SERVICE DEFAULT>')}
     end
 
     context 'with override_uuid enabled' do
@@ -112,10 +115,23 @@ describe 'nova::migration::libvirt' do
         {
           :live_migration_tunnelled          => true,
           :live_migration_completion_timeout => '1500',
+          :live_migration_timeout_action     => 'force_complete',
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('1500') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('force_complete') }
+    end
+
+    context 'with live migration auto converge on' do
+      let :params do
+        {
+          :live_migration_permit_post_copy     => false,
+          :live_migration_permit_auto_converge => true,
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with(:value => false) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with(:value => true) }
     end
 
     context 'with auth set to sasl' do
@@ -139,6 +155,18 @@ describe 'nova::migration::libvirt' do
       it { is_expected.not_to contain_libvirtd_config('auth_tcp') }
     end
 
+    context 'with certificates set and tls enabled' do
+      let :params do
+        {
+          :transport => 'tls',
+          :ca_file   => '/ca',
+          :crl_file  => '/crl',
+        }
+      end
+      it { is_expected.to contain_libvirtd_config('ca_file').with_value("\"/ca\"") }
+      it { is_expected.to contain_libvirtd_config('crl_file').with_value("\"/crl\"") }
+    end
+
     context 'with auth set to an invalid setting' do
       let :params do
         {
@@ -146,7 +174,7 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { expect { is_expected.to contain_class('nova::compute::libvirt') }.to \
-        raise_error(Puppet::Error, /Valid options for auth are none and sasl./) }
+        raise_error(Puppet::Error) }
     end
 
     context 'when not configuring libvirt' do
@@ -227,6 +255,123 @@ describe 'nova::migration::libvirt' do
 
   end
 
+  shared_examples_for 'nova migration with libvirt in Debian' do
+    context 'with libvirt < 5.6' do
+      let :params do
+        { :transport       => 'tls',
+          :libvirt_version => '4.0' }
+      end
+
+      it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
+        :path  => '/etc/default/libvirtd',
+        :line  => 'libvirtd_opts="-l"',
+        :match => 'libvirtd_opts=',
+        :tag   => 'libvirt-file_line',
+      ) }
+      it { is_expected.to_not contain_service('libvirtd-tls') }
+      it { is_expected.to_not contain_service('libvirtd-tcp') }
+    end
+
+    context 'with libvirt >= 5.6' do
+      context 'with tls transport' do
+        let :params do
+          { :transport       => 'tls',
+            :libvirt_version => '6.0' }
+        end
+
+        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
+          :path  => '/etc/default/libvirtd',
+          :line  => 'libvirtd_opts=',
+          :match => 'libvirtd_opts=',
+          :tag   => 'libvirt-file_line',
+        ) }
+        it { is_expected.to contain_service('libvirtd-tls').with(
+          :name   => 'libvirtd-tls.socket',
+          :ensure => 'running',
+          :enable => true,
+          )}
+      end
+
+      context 'with tcp transport' do
+        let :params do
+          { :transport       => 'tcp',
+            :libvirt_version => '6.0' }
+        end
+
+        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(
+          :path  => '/etc/default/libvirtd',
+          :line  => 'libvirtd_opts=',
+          :match => 'libvirtd_opts=',
+          :tag   => 'libvirt-file_line',
+        ) }
+        it { is_expected.to contain_service('libvirtd-tcp').with(
+          :name   => 'libvirtd-tcp.socket',
+          :ensure => 'running',
+          :enable => true,
+          )}
+      end
+    end
+  end
+
+  shared_examples_for 'nova migration with libvirt in RedHat' do
+    context 'with libvirt < 5.6' do
+      let :params do
+        { :transport       => 'tls',
+          :libvirt_version => '4.5' }
+      end
+
+      it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
+        :path  => '/etc/sysconfig/libvirtd',
+        :line  => 'LIBVIRTD_ARGS="--listen"',
+        :match => '^LIBVIRTD_ARGS=',
+        :tag   => 'libvirt-file_line',
+      )}
+      it { is_expected.to_not contain_service('libvirtd-tls') }
+      it { is_expected.to_not contain_service('libvirtd-tcp') }
+    end
+
+    context 'with libvirt >= 5.6' do
+
+      context 'with tls transport' do
+        let :params do
+          { :transport       => 'tls',
+            :libvirt_version => '5.6' }
+        end
+
+        it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
+          :path  => '/etc/sysconfig/libvirtd',
+          :line  => 'LIBVIRTD_ARGS=',
+          :match => '^LIBVIRTD_ARGS=',
+          :tag   => 'libvirt-file_line',
+        )}
+        it { is_expected.to contain_service('libvirtd-tls').with(
+          :name   => 'libvirtd-tls.socket',
+          :ensure => 'running',
+          :enable => true,
+        )}
+      end
+
+      context 'with tcp transport' do
+        let :params do
+          { :transport       => 'tcp',
+            :libvirt_version => '5.6' }
+        end
+
+        it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(
+          :path  => '/etc/sysconfig/libvirtd',
+          :line  => 'LIBVIRTD_ARGS=',
+          :match => '^LIBVIRTD_ARGS=',
+          :tag   => 'libvirt-file_line',
+        )}
+        it { is_expected.to contain_service('libvirtd-tcp').with(
+          :name   => 'libvirtd-tcp.socket',
+          :ensure => 'running',
+          :enable => true,
+        )}
+      end
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -235,16 +380,13 @@ describe 'nova::migration::libvirt' do
         facts.merge!(OSDefaults.get_facts({ :os_workers => 5 }))
       end
 
-      let (:platform_params) do
-        case facts[:osfamily]
-        when 'Debian'
-            it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => 'libvirtd_opts="-l"') }
-        when 'RedHat'
-            it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
-        end
+      it_behaves_like 'nova migration with libvirt'
+      case facts[:osfamily]
+      when 'Debian'
+        it_behaves_like 'nova migration with libvirt in Debian'
+      when 'RedHat'
+        it_behaves_like 'nova migration with libvirt in RedHat'
       end
-
-      it_configures 'nova migration with libvirt'
     end
   end
 end
